@@ -23,7 +23,6 @@
  */
 
 #include "config.h"
-#include "i18n.h"
 
 #include <iostream>
 #include <algorithm>
@@ -37,6 +36,8 @@
 #include "rpackagelister.h"
 #include "rpackage.h"
 
+#include "i18n.h"
+
 using namespace std;
 
 const char *RPFStatus = _("Status");
@@ -421,6 +422,13 @@ bool RPatternPackageFilter::write(ofstream &out, string pad)
     
     for (int i = 0; i < count(); i++) {
 	getPattern(i, type, pat, excl);
+
+	// strip away '"' in string -> if not a pattern containing '"' will
+	// cause a segfault on startup
+	for(int i=0;i<pat.size();i++)
+	   if(pat[i]=='"')
+	      pat[i]=' ';
+
 	out << pad + "  " + TypeName[(int)type] + ";"
 	    << " \"" << pat << "\"; "  
 	    << (excl ? "true;" : "false;") << endl;
@@ -463,7 +471,7 @@ bool RPatternPackageFilter::read(Configuration &conf, string key)
 RPatternPackageFilter::RPatternPackageFilter(RPatternPackageFilter &f)
 {
     //cout << "RPatternPackageFilter(&RPatternPackageFilter f)" << endl;
-    for(int i=0;i<f._patterns.size();i++) {
+    for(unsigned int i=0;i<f._patterns.size();i++) {
 	addPattern(f._patterns[i].where,
 		   f._patterns[i].pattern,
 		   f._patterns[i].exclusive);
@@ -478,8 +486,8 @@ void RPatternPackageFilter::clear()
     //}
     
     // give back all the memory
-    for(int i=0;i<_patterns.size();i++) {
-	for(int j=0;j<_patterns[i].regexps.size();j++) {
+    for(unsigned int i=0;i<_patterns.size();i++) {
+	for(unsigned int j=0;j<_patterns[i].regexps.size();j++) {
 	    regfree(_patterns[i].regexps[j]);
 	    delete (regex_t*)_patterns[i].regexps[j];
 	}
