@@ -22,7 +22,7 @@
 #include <apt-pkg/configuration.h>
 #include <apt-pkg/strutl.h>
 #include "gtkpkglist.h"
-#include "gsynaptic.h"
+#include "rgmisc.h"
 
 using namespace std;
 
@@ -449,23 +449,7 @@ gtk_pkg_list_get_value (GtkTreeModel *tree_model,
     {
 	if(pkg == NULL) return;
 	GdkColor *bg;
-	RPackage::MarkedStatus s = pkg->getMarkedStatus();
-	RPackage::PackageStatus status = pkg->getStatus();
-	int other = pkg->getOtherStatus();
-	
-	if (pkg->wouldBreak()) {
-	    bg =  StatusColors[(int)RPackage::MBroken];
-	} else if (other & RPackage::OPinned) {
-	    bg = StatusColors[(int)RPackage::MPinned];
-	} else if (s == RPackage::MKeep 
-		   && status == RPackage::SInstalledOutdated) {
-	    bg = StatusColors[RPackage::MHeld];
-	} else if ((other & RPackage::ONew) && 
-		   !s == RPackage::MInstall) {
-	    bg = StatusColors[(int)RPackage::MNew];
-	} else {
-	    bg = StatusColors[(int)s];
-	}
+	bg = RPackageStatus::pkgStatus.getBgColor(pkg);
 	g_value_set_boxed(value, bg);
 	break;
     }
@@ -473,23 +457,7 @@ gtk_pkg_list_get_value (GtkTreeModel *tree_model,
     {
  	if(pkg == NULL) return;
 	GdkPixbuf *pix;
-	
-	RPackage::MarkedStatus s = pkg->getMarkedStatus();
-	int other = pkg->getOtherStatus();
-	
-	if (pkg->wouldBreak()) {
-	    pix = StatusPixbuf[(int)RPackage::MBroken];
-	} else if (other & RPackage::OPinned) {
-	    pix = StatusPixbuf[(int)RPackage::MPinned];
-	} else if (s == RPackage::MKeep 
-		   && pkg->getStatus() == RPackage::SInstalledOutdated) {
-	    pix = StatusPixbuf[RPackage::MHeld];
-	} else if ((other & RPackage::ONew) && 
-		   !pkg->getMarkedStatus() == RPackage::MInstall) {
-	    pix = StatusPixbuf[(int)RPackage::MNew];
-	} else {
-	    pix = StatusPixbuf[(int)s];
-	}
+	pix = RPackageStatus::pkgStatus.getPixbuf(pkg);
 	g_value_set_object(value, pix);
 	break;
     }
