@@ -1,8 +1,10 @@
 /* rwmainwindow.cc - main window of the app
  * 
- * Copyright (c) 2000, 2001 Conectiva S/A 
+ * Copyright (c) 2000-2003 Conectiva S/A 
+ *               2002 Michael Vogt <mvo@debian.org>
  * 
  * Author: Alfredo K. Kojima <kojima@conectiva.com.br>
+ *         Michael Vogt <mvo@debian.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -31,6 +33,7 @@
 
 #include <stdio.h>
 #include <ctype.h>
+#include <cmath>
 
 #include <apt-pkg/strutl.h>
 #include <apt-pkg/error.h>
@@ -122,6 +125,7 @@ int RWMainWindow::numberOfRows(WMTableViewDelegate *self, WMTableView *table)
 }
 
 
+// TODO: add displayPackages set like in (rgmainwindow) 
 void *RWMainWindow::valueForCell(WMTableViewDelegate *self,
 				 WMTableColumn *column, int row)
 {
@@ -163,14 +167,13 @@ void *RWMainWindow::valueForCell(WMTableViewDelegate *self,
 	break;
 
      case CNewest:
-	if (elem->downloadable()) 
-	    text = elem->availableVersion();
-	if (!text)
-	    text = "";
+	 text = elem->availableVersion();
+	 if (!text)
+	     text = "";
 	break;
 	
      case CSummary:
-	strncpy(buffer, elem->summary().c_str(), sizeof(buffer));	
+	strncpy(buffer, elem->summary(), sizeof(buffer));	
 	data[0] = (void*)buffer;
 	data[1] = NULL;
 	
@@ -216,7 +219,7 @@ void RWMainWindow::clickedDepList(WMWidget *self, void *data)
     RWMainWindow *me = (RWMainWindow*)data;
     WMListItem *item = WMGetListSelectedItem(me->_depList);
 
-    WMSetLabelText(me->_depInfoL, strchr(item->text, '\001'));
+    WMSetLabelText(me->_depInfoL, strchr(item->text, '\001')+1);
 }
 
 
@@ -311,7 +314,7 @@ void RWMainWindow::saveFilterAction(void *self, RWFilterWindow *rwin)
 void RWMainWindow::closeFilterAction(void *self, RWFilterWindow *rwin)
 {
     RWMainWindow *me = (RWMainWindow*)self;
-    RPackage *pkg = me->selectedPackage();
+    //RPackage *pkg = me->selectedPackage();
     Bool filterEditable;
     
     filterEditable = WMGetPopUpButtonSelectedItem(me->_popup) != 0;
@@ -411,7 +414,7 @@ void RWMainWindow::changedFilter(WMWidget *self, void *data)
     int filter = WMGetPopUpButtonSelectedItem((WMPopUpButton*)self);
     RWMainWindow *mainw = (RWMainWindow*)data;
     RPackage *pkg = mainw->selectedPackage();
-    int i;
+    //int i;
     
     mainw->setInterfaceLocked(true);
     
@@ -640,7 +643,7 @@ void RWMainWindow::proceedClicked(WMWidget *self, void *data)
     // fetch packages
     RWFetchProgress *fprogress = new RWFetchProgress(me);
     fprogress->setTitle(_("Retrieving Package Files"));
-
+    
 #ifdef HAVE_RPM
     RWInstallProgress *iprogress = new RWInstallProgress(me);
 #else
@@ -648,7 +651,8 @@ void RWMainWindow::proceedClicked(WMWidget *self, void *data)
 	new RWDummyInstallProgress(WMWidgetScreen(me->_win));
 #endif
     
-    bool result = me->_lister->commitChanges(fprogress, iprogress);
+    //bool result = me->_lister->commitChanges(fprogress, iprogress);
+    me->_lister->commitChanges(fprogress, iprogress);
     
     delete fprogress;
     delete iprogress;
@@ -679,7 +683,7 @@ bool RWMainWindow::showErrors()
     WMLabel *label;
     string message;
     WMFont *font;
-    int widest = 0;
+    unsigned int widest = 0;
     int lines;
     char *type;
     int theight;
@@ -692,7 +696,7 @@ bool RWMainWindow::showErrors()
     else
 	type = _("Warning");
     
-    panel = WMCreateGenericPanel(scr, _win, type, "OK", NULL);
+    panel = WMCreateGenericPanel(scr, _win, type, _("OK"), NULL);
 
     sbox = WMCreateScrollView(panel->content);
     WMMapWidget(sbox);
@@ -717,7 +721,7 @@ bool RWMainWindow::showErrors()
 	_error->PopMessage(tmp);
        
         // ignore some stupid error messages
-	if (tmp == "Tried to dequeue a fetching object")
+	if (tmp == _("Tried to dequeue a fetching object"))
 	   continue;
 
 	if (message.empty())
@@ -728,7 +732,7 @@ bool RWMainWindow::showErrors()
  
     {
 	const char *b, *e = message.c_str();
-	int w;
+	unsigned int w;
 
 	while (e) {
 	    b = e + 1;
@@ -855,6 +859,7 @@ void RWMainWindow::notifyChange(RPackage *pkg)
 
 void RWMainWindow::refreshTable(RPackage *selectedPkg)
 {    
+  static bool first_run = true;
     _tempKluge = true;
 
     WMReloadTableView(_table);
@@ -867,6 +872,9 @@ void RWMainWindow::refreshTable(RPackage *selectedPkg)
 	if (index >= 0)
 	    WMSelectTableViewRow(_table, index);
     }
+    if(first_run)
+      first_run=false;
+
 }
 
 
@@ -929,7 +937,7 @@ void RWMainWindow::updatePackageStatus(RPackage *pkg)
 	
      case RPackage::MDowngrade:
 	// not handled yet
-	puts("OH SHIT!!");
+	puts(_("OH SHIT!!"));
 	break;
 	
      case RPackage::MRemove:
@@ -946,8 +954,8 @@ void RWMainWindow::updatePackageStatus(RPackage *pkg)
 	if (mstatus == RPackage::MKeep
 	    && status == RPackage::SInstalledOutdated) {
 	    WMSetLabelImage(_stateL, StatusPixmaps[RPackage::MHeld]);
-	}
-	WMSetLabelImage(_stateL, StatusPixmaps[(int)mstatus]);
+	} else
+	    WMSetLabelImage(_stateL, StatusPixmaps[(int)mstatus]);
     }
     
     WMSetButtonSelected(_currentB, True);
@@ -957,7 +965,7 @@ void RWMainWindow::updatePackageStatus(RPackage *pkg)
 void RWMainWindow::navigateTable(char direction)
 {
     WMArray *array = WMGetTableViewSelectedRows(_table);
-    int index;
+    unsigned int index;
 
     if (WMGetArrayItemCount(array) == 0)
 	index = 0;
@@ -1003,7 +1011,7 @@ void RWMainWindow::navigateTable(char direction)
 void RWMainWindow::keyPressHandler(XEvent *event, void *data)
 {
     RWMainWindow *me = (RWMainWindow*)data;
-    Display *dpy = event->xany.display;
+    //Display *dpy = event->xany.display;
     char buffer[32];
     int count;
     KeySym ksym;
@@ -1179,7 +1187,7 @@ void RWMainWindow::updatePackageInfo(RPackage *pkg)
     
     // name/summary
     WMSetLabelText(_nameL, (char*)pkg->name());
-    WMSetLabelText(_summL, (char*)pkg->summary().c_str());
+    WMSetLabelText(_summL, (char*)pkg->summary());
     
     // package info
     
@@ -1187,8 +1195,8 @@ void RWMainWindow::updatePackageInfo(RPackage *pkg)
     appendTag(bufPtr, bufSize, _("Section"), pkg->section());
     appendTag(bufPtr, bufSize, _("Priority"), pkg->priority());
     /*XXX
-    appendTag(bufPtr, bufSize, "Maintainer", pkg->maintainer().c_str());
-    appendTag(bufPtr, bufSize, "Vendor", pkg->vendor());
+    appendTag(bufPtr, bufSize, _("Maintainer"), pkg->maintainer().c_str());
+    appendTag(bufPtr, bufSize, _("Vendor"), pkg->vendor());
      */
     
     // installed version info
@@ -1204,13 +1212,12 @@ void RWMainWindow::updatePackageInfo(RPackage *pkg)
     appendText(bufPtr, bufSize, _("\nAvailable Package:\n"));
     
     
-    appendTag(bufPtr, bufSize, _("    Version"),
-	      pkg->downloadable() ? pkg->availableVersion() : _("N/A"));
-    size = pkg->availableSize();
+    appendTag(bufPtr, bufSize, _("    Version"), pkg->availableVersion());
+    size = pkg->availableInstalledSize();
     appendTag(bufPtr, bufSize, _("    Size"),
 	      size < 0 ?  _("N/A") : SizeToStr(size).c_str());
 
-    size = pkg->packageSize();
+    size = pkg->availablePackageSize();
     appendTag(bufPtr, bufSize, _("    Package Size"), 
 	      size < 0 ?  _("N/A") : SizeToStr(size).c_str());
 
@@ -1443,6 +1450,8 @@ RWMainWindow::RWMainWindow(WMScreen *scr, RPackageLister *packLister)
 #endif
     _tempKluge = false;
     
+    _unsavedChanges = false;
+    
     _interfaceLocked = 0;
     _lockWindow = None;
 
@@ -1469,17 +1478,17 @@ RWMainWindow::RWMainWindow(WMScreen *scr, RPackageLister *packLister)
     
     StatusPixmaps[(int)RPackage::MKeep] = NULL;
     StatusPixmaps[(int)RPackage::MInstall] = 
-	WMCreatePixmapFromXPMData(scr, installM_xpm);
+	WMCreatePixmapFromXPMData(scr, (char**)installM_xpm);
     StatusPixmaps[(int)RPackage::MUpgrade] =
-	WMCreatePixmapFromXPMData(scr, upgradeM_xpm);
+	WMCreatePixmapFromXPMData(scr, (char**)upgradeM_xpm);
     StatusPixmaps[(int)RPackage::MDowngrade] =
-	WMCreatePixmapFromXPMData(scr, downgradeM_xpm);
+	WMCreatePixmapFromXPMData(scr,  (char**)downgradeM_xpm);
     StatusPixmaps[(int)RPackage::MRemove] =
-	WMCreatePixmapFromXPMData(scr, removeM_xpm);
+	WMCreatePixmapFromXPMData(scr,  (char**)removeM_xpm);
     StatusPixmaps[(int)RPackage::MHeld] =
-	WMCreatePixmapFromXPMData(scr, heldM_xpm);
+	WMCreatePixmapFromXPMData(scr,  (char**)heldM_xpm);
     StatusPixmaps[7] = 
-	WMCreatePixmapFromXPMData(scr, brokenM_xpm);
+	WMCreatePixmapFromXPMData(scr,  (char**)brokenM_xpm);
     StatusPixmaps[8] = _alertPix;
 }
 
@@ -1505,7 +1514,7 @@ void RWMainWindow::buildInterface(WMScreen *scr)
 			 keyPressHandler, this);
     
     
-    _alertPix = WMCreatePixmapFromXPMData(scr, alert_xpm);
+    _alertPix = WMCreatePixmapFromXPMData(scr,  (char**)alert_xpm);
 
     font = WMSystemFontOfSize(scr, 10);
     bfont = WMBoldSystemFontOfSize(scr, 12);
@@ -1593,12 +1602,12 @@ void RWMainWindow::buildInterface(WMScreen *scr)
     WMAddBoxSubviewAtEnd(hbox, WMWidgetView(button), False, True, 
 			 buttonWidth, 0, 5);
 
-//    button = makeButton(hbox, _("Repositories"), largeBtns ? sources_xpm : NULL, font);
-//    WMSetButtonAction(button, proceedClicked, this);
- //   WMSetBalloonTextForView(_("Manage package repositories"),
-	//		    WMWidgetView(button));
-//    WMAddBoxSubviewAtEnd(hbox, WMWidgetView(button), False, True,
-	//		 buttonWidth, 0, 5); 
+//     button = makeButton(hbox, _("Repositories"), largeBtns ? sources_xpm : NULL, font);
+//     WMSetButtonAction(button, showSourcesWindow, this);
+//    WMSetBalloonTextForView(_("Manage package repositories"),
+// 		    WMWidgetView(button));
+//     WMAddBoxSubviewAtEnd(hbox, WMWidgetView(button), False, True,
+// 		 buttonWidth, 0, 5); 
 
     WMReleaseFont(font);
     
@@ -1719,8 +1728,8 @@ void RWMainWindow::buildInterface(WMScreen *scr)
 	WMSetPopUpButtonAction(_depP, changedDepView, this);
 	WMMapWidget(_depP);
 	WMAddBoxSubview(vb, WMWidgetView(_depP), False, True, 20, 0, 5);
-	WMAddPopUpButtonItem(_depP, _("Dependencies"));
-	WMAddPopUpButtonItem(_depP, _("Dependents"));
+	WMAddPopUpButtonItem(_depP, _("What it depends on"));
+	WMAddPopUpButtonItem(_depP, _("What depends on it"));
 #ifndef HAVE_RPM
 	WMAddPopUpButtonItem(_depP, _("Suggested and Recommended"));
 #endif
@@ -1900,12 +1909,12 @@ void RWMainWindow::buildInterface(WMScreen *scr)
 	WMAddBoxSubview(vbox, WMWidgetView(hbox), False, False, 22, 0, 0);
 
 	button = WMCreateCommandButton(hbox);
-	WMSetButtonText(button, "Unselect All");
+	WMSetButtonText(button, _("Unselect All"));
 	WMAddBoxSubview(hbox, WMWidgetView(button), False, True, 100, 0, 10);
 
 	WMPopUpButton *advCmd = WMCreatePopUpButton(hbox);
 	WMSetPopUpButtonPullsDown(advCmd, True);
-	WMSetPopUpButtonText(advCmd, "Advanced Dynamic Turbo Filters");
+	WMSetPopUpButtonText(advCmd, _("Advanced Dynamic Turbo Filters"));
 	WMAddBoxSubview(hbox, WMWidgetView(advCmd), True, True, 40, 0, 0);
 
 	WMMapSubwidgets(hbox);
@@ -2017,6 +2026,7 @@ void RWMainWindow::setStatusText(char *text)
     }
     
     WMSetButtonEnabled(_proceedB, (toinstall + toremove) != 0);
+    _unsavedChanges = (toinstall + toremove) != 0;
     
     XFlush(WMScreenDisplay(WMWidgetScreen(_win)));
 }
@@ -2064,8 +2074,10 @@ void RWMainWindow::close()
     if (_interfaceLocked > 0)
 	return;
     
-    if (WMRunAlertPanel(WMWidgetScreen(_win), _win, _("Warning"),
-			_("Are you sure you want to quit Synaptic?"),
+    if (_unsavedChanges == false ||
+	WMRunAlertPanel(WMWidgetScreen(_win), _win, _("Warning"),
+			_("There are unsaved changes, are you sure\n"
+			  "you want to quit Synaptic?"),
 			_("Quit"), _("Cancel"), NULL) == WAPRDefault) {
 
 	_error->Discard();
@@ -2086,7 +2098,7 @@ void RWMainWindow::setInterfaceLocked(bool flag)
     Display *dpy = WMScreenDisplay(scr);
 
     if (flag) {
-	WMRect rect;
+      //WMRect rect;
 
 	_interfaceLocked++;
 	if (_interfaceLocked > 1)
